pub struct EntityInitQuery {
pub entity_id: &'static EntityId,
pub uuid: &'static UniqueId,
pub kind: &'static EntityKind,
pub look: &'static Look,
pub head_yaw: &'static HeadYaw,
pub on_ground: &'static OnGround,
pub object_data: &'static ObjectData,
pub velocity: &'static Velocity,
pub tracked_data: &'static TrackedData,
}Fields
entity_id: &'static EntityIduuid: &'static UniqueIdkind: &'static EntityKindlook: &'static Lookhead_yaw: &'static HeadYawon_ground: &'static OnGroundobject_data: &'static ObjectDatavelocity: &'static Velocitytracked_data: &'static TrackedDataTrait Implementations
Sourceimpl QueryData for EntityInitQuery
impl QueryData for EntityInitQuery
Sourceunsafe fn fetch<'__w, '__s>(
_state: &'__s <EntityInitQuery as WorldQuery>::State,
_fetch: &mut <EntityInitQuery as WorldQuery>::Fetch<'__w>,
_entity: Entity,
_table_row: TableRow,
) -> Option<<EntityInitQuery as QueryData>::Item<'__w, '__s>>
unsafe fn fetch<'__w, '__s>( _state: &'__s <EntityInitQuery as WorldQuery>::State, _fetch: &mut <EntityInitQuery as WorldQuery>::Fetch<'__w>, _entity: Entity, _table_row: TableRow, ) -> Option<<EntityInitQuery as QueryData>::Item<'__w, '__s>>
SAFETY: we call fetch for each member that implements Fetch.
Sourceconst IS_READ_ONLY: bool = true
const IS_READ_ONLY: bool = true
True if this query is read-only and may not perform mutable access.
Sourceconst IS_ARCHETYPAL: bool
const IS_ARCHETYPAL: bool
Returns true if (and only if) this query data relies strictly on archetypes to limit which
entities are accessed by the Query. Read more
Sourcetype ReadOnly = EntityInitQuery
type ReadOnly = EntityInitQuery
The read-only variant of this
QueryData, which satisfies the ReadOnlyQueryData trait.Sourcetype Item<'__w, '__s> = EntityInitQueryItem<'__w, '__s>
type Item<'__w, '__s> = EntityInitQueryItem<'__w, '__s>
The item returned by this
WorldQuery
This will be the data retrieved by the query,
and is visible to the end user when calling e.g. Query<Self>::get.Sourcefn shrink<'__wlong, '__wshort, '__s>(
item: <EntityInitQuery as QueryData>::Item<'__wlong, '__s>,
) -> <EntityInitQuery as QueryData>::Item<'__wshort, '__s>where
'__wlong: '__wshort,
fn shrink<'__wlong, '__wshort, '__s>(
item: <EntityInitQuery as QueryData>::Item<'__wlong, '__s>,
) -> <EntityInitQuery as QueryData>::Item<'__wshort, '__s>where
'__wlong: '__wshort,
This function manually implements subtyping for the query items.
Sourcefn provide_extra_access(
state: &mut <EntityInitQuery as WorldQuery>::State,
access: &mut Access,
available_access: &Access,
)
fn provide_extra_access( state: &mut <EntityInitQuery as WorldQuery>::State, access: &mut Access, available_access: &Access, )
Offers additional access above what we requested in
update_component_access.
Implementations may add additional access that is a subset of available_access
and does not conflict with anything in access,
and must update access to include that access. Read moreSourcefn iter_access(
_state: &<EntityInitQuery as WorldQuery>::State,
) -> impl Iterator<Item = EcsAccessType<'_>>
fn iter_access( _state: &<EntityInitQuery as WorldQuery>::State, ) -> impl Iterator<Item = EcsAccessType<'_>>
Returns an iterator over the access needed by
QueryData::fetch. Access conflicts are usually
checked in WorldQuery::update_component_access, but in certain cases this method can be useful to implement
a way of checking for access conflicts in a non-allocating way.Sourceimpl ReleaseStateQueryData for EntityInitQuerywhere
&'static EntityId: for<'__a> ReleaseStateQueryData,
&'static UniqueId: for<'__a> ReleaseStateQueryData,
&'static EntityKind: for<'__a> ReleaseStateQueryData,
&'static Look: for<'__a> ReleaseStateQueryData,
&'static HeadYaw: for<'__a> ReleaseStateQueryData,
&'static OnGround: for<'__a> ReleaseStateQueryData,
&'static ObjectData: for<'__a> ReleaseStateQueryData,
&'static Velocity: for<'__a> ReleaseStateQueryData,
&'static TrackedData: for<'__a> ReleaseStateQueryData,
impl ReleaseStateQueryData for EntityInitQuerywhere
&'static EntityId: for<'__a> ReleaseStateQueryData,
&'static UniqueId: for<'__a> ReleaseStateQueryData,
&'static EntityKind: for<'__a> ReleaseStateQueryData,
&'static Look: for<'__a> ReleaseStateQueryData,
&'static HeadYaw: for<'__a> ReleaseStateQueryData,
&'static OnGround: for<'__a> ReleaseStateQueryData,
&'static ObjectData: for<'__a> ReleaseStateQueryData,
&'static Velocity: for<'__a> ReleaseStateQueryData,
&'static TrackedData: for<'__a> ReleaseStateQueryData,
Sourcefn release_state<'__w>(
_item: <EntityInitQuery as QueryData>::Item<'__w, '_>,
) -> <EntityInitQuery as QueryData>::Item<'__w, 'static>
fn release_state<'__w>( _item: <EntityInitQuery as QueryData>::Item<'__w, '_>, ) -> <EntityInitQuery as QueryData>::Item<'__w, 'static>
Releases the borrow from the query state by converting an item to have a
'static state lifetime.Sourceimpl WorldQuery for EntityInitQuery
impl WorldQuery for EntityInitQuery
Sourceunsafe fn set_archetype<'__w, '__s>(
_fetch: &mut <EntityInitQuery as WorldQuery>::Fetch<'__w>,
_state: &'__s <EntityInitQuery as WorldQuery>::State,
_archetype: &'__w Archetype,
_table: &'__w Table,
)
unsafe fn set_archetype<'__w, '__s>( _fetch: &mut <EntityInitQuery as WorldQuery>::Fetch<'__w>, _state: &'__s <EntityInitQuery as WorldQuery>::State, _archetype: &'__w Archetype, _table: &'__w Table, )
SAFETY: we call set_archetype for each member that implements Fetch
Sourceunsafe fn set_table<'__w, '__s>(
_fetch: &mut <EntityInitQuery as WorldQuery>::Fetch<'__w>,
_state: &'__s <EntityInitQuery as WorldQuery>::State,
_table: &'__w Table,
)
unsafe fn set_table<'__w, '__s>( _fetch: &mut <EntityInitQuery as WorldQuery>::Fetch<'__w>, _state: &'__s <EntityInitQuery as WorldQuery>::State, _table: &'__w Table, )
SAFETY: we call set_table for each member that implements Fetch
Sourceconst IS_DENSE: bool
const IS_DENSE: bool
Returns true if (and only if) every table of every archetype matched by this fetch contains
all of the matched components. Read more
Sourcetype Fetch<'__w> = EntityInitQueryFetch<'__w>
type Fetch<'__w> = EntityInitQueryFetch<'__w>
Per archetype/table state retrieved by this
WorldQuery to compute Self::Item for each entity.Sourcetype State = EntityInitQueryState
type State = EntityInitQueryState
State used to construct a
Self::Fetch. This will be cached inside QueryState,
so it is best to move as much data / computation here as possible to reduce the cost of
constructing Self::Fetch.Sourcefn shrink_fetch<'__wlong, '__wshort>(
fetch: <EntityInitQuery as WorldQuery>::Fetch<'__wlong>,
) -> <EntityInitQuery as WorldQuery>::Fetch<'__wshort>where
'__wlong: '__wshort,
fn shrink_fetch<'__wlong, '__wshort>(
fetch: <EntityInitQuery as WorldQuery>::Fetch<'__wlong>,
) -> <EntityInitQuery as WorldQuery>::Fetch<'__wshort>where
'__wlong: '__wshort,
This function manually implements subtyping for the query fetches.
Sourceunsafe fn init_fetch<'__w, '__s>(
_world: UnsafeWorldCell<'__w>,
state: &'__s <EntityInitQuery as WorldQuery>::State,
_last_run: Tick,
_this_run: Tick,
) -> <EntityInitQuery as WorldQuery>::Fetch<'__w>
unsafe fn init_fetch<'__w, '__s>( _world: UnsafeWorldCell<'__w>, state: &'__s <EntityInitQuery as WorldQuery>::State, _last_run: Tick, _this_run: Tick, ) -> <EntityInitQuery as WorldQuery>::Fetch<'__w>
Creates a new instance of
Self::Fetch,
by combining data from the World with the cached Self::State.
Readonly accesses resources registered in WorldQuery::update_component_access. Read moreSourcefn update_component_access(
state: &<EntityInitQuery as WorldQuery>::State,
_access: &mut FilteredAccess,
)
fn update_component_access( state: &<EntityInitQuery as WorldQuery>::State, _access: &mut FilteredAccess, )
Sourcefn init_nested_access(
state: &<EntityInitQuery as WorldQuery>::State,
_system_name: Option<&str>,
_component_access_set: &mut FilteredAccessSet,
_world: UnsafeWorldCell<'_>,
)
fn init_nested_access( state: &<EntityInitQuery as WorldQuery>::State, _system_name: Option<&str>, _component_access_set: &mut FilteredAccessSet, _world: UnsafeWorldCell<'_>, )
Adds any component accesses to other entities used by this
WorldQuery. Read moreSourcefn init_state(world: &mut World) -> EntityInitQueryState
fn init_state(world: &mut World) -> EntityInitQueryState
Creates and initializes a
State for this WorldQuery type.Sourcefn get_state(components: &Components) -> Option<EntityInitQueryState>
fn get_state(components: &Components) -> Option<EntityInitQueryState>
Sourcefn matches_component_set(
state: &<EntityInitQuery as WorldQuery>::State,
_set_contains_id: &impl Fn(ComponentId) -> bool,
) -> bool
fn matches_component_set( state: &<EntityInitQuery as WorldQuery>::State, _set_contains_id: &impl Fn(ComponentId) -> bool, ) -> bool
Sourcefn update_archetypes(
_state: &mut <EntityInitQuery as WorldQuery>::State,
_world: UnsafeWorldCell<'_>,
)
fn update_archetypes( _state: &mut <EntityInitQuery as WorldQuery>::State, _world: UnsafeWorldCell<'_>, )
Called when the query state is updating its archetype cache.
This can be used by nested queries to update their internal archetype caches.
impl ArchetypeQueryData for EntityInitQuerywhere
&'static EntityId: for<'__a> ArchetypeQueryData,
&'static UniqueId: for<'__a> ArchetypeQueryData,
&'static EntityKind: for<'__a> ArchetypeQueryData,
&'static Look: for<'__a> ArchetypeQueryData,
&'static HeadYaw: for<'__a> ArchetypeQueryData,
&'static OnGround: for<'__a> ArchetypeQueryData,
&'static ObjectData: for<'__a> ArchetypeQueryData,
&'static Velocity: for<'__a> ArchetypeQueryData,
&'static TrackedData: for<'__a> ArchetypeQueryData,
impl IterQueryData for EntityInitQuerywhere
&'static EntityId: for<'__a> IterQueryData,
&'static UniqueId: for<'__a> IterQueryData,
&'static EntityKind: for<'__a> IterQueryData,
&'static Look: for<'__a> IterQueryData,
&'static HeadYaw: for<'__a> IterQueryData,
&'static OnGround: for<'__a> IterQueryData,
&'static ObjectData: for<'__a> IterQueryData,
&'static Velocity: for<'__a> IterQueryData,
&'static TrackedData: for<'__a> IterQueryData,
impl ReadOnlyQueryData for EntityInitQuery
impl SingleEntityQueryData for EntityInitQuerywhere
&'static EntityId: for<'__a> SingleEntityQueryData,
&'static UniqueId: for<'__a> SingleEntityQueryData,
&'static EntityKind: for<'__a> SingleEntityQueryData,
&'static Look: for<'__a> SingleEntityQueryData,
&'static HeadYaw: for<'__a> SingleEntityQueryData,
&'static OnGround: for<'__a> SingleEntityQueryData,
&'static ObjectData: for<'__a> SingleEntityQueryData,
&'static Velocity: for<'__a> SingleEntityQueryData,
&'static TrackedData: for<'__a> SingleEntityQueryData,