pub struct EntityInitQuery {
pub entity_id: &'static EntityId,
pub uuid: &'static UniqueId,
pub kind: &'static EntityKind,
pub look: &'static Look,
pub head_yaw: &'static HeadYaw,
pub on_ground: &'static OnGround,
pub object_data: &'static ObjectData,
pub velocity: &'static Velocity,
pub tracked_data: &'static TrackedData,
}Fields
entity_id: &'static EntityIduuid: &'static UniqueIdkind: &'static EntityKindlook: &'static Lookhead_yaw: &'static HeadYawon_ground: &'static OnGroundobject_data: &'static ObjectDatavelocity: &'static Velocitytracked_data: &'static TrackedDataTrait Implementations
Sourceimpl QueryData for EntityInitQuery
SAFETY: we assert fields are readonly below
impl QueryData for EntityInitQuery
SAFETY: we assert fields are readonly below
Sourcetype ReadOnly = EntityInitQuery
type ReadOnly = EntityInitQuery
The read-only variant of this
QueryData, which satisfies the ReadOnlyQueryData trait.Sourceimpl WorldQuery for EntityInitQuery
impl WorldQuery for EntityInitQuery
Sourceunsafe fn set_archetype<'__w>(
_fetch: &mut <EntityInitQuery as WorldQuery>::Fetch<'__w>,
_state: &<EntityInitQuery as WorldQuery>::State,
_archetype: &'__w Archetype,
_table: &'__w Table,
)
unsafe fn set_archetype<'__w>( _fetch: &mut <EntityInitQuery as WorldQuery>::Fetch<'__w>, _state: &<EntityInitQuery as WorldQuery>::State, _archetype: &'__w Archetype, _table: &'__w Table, )
SAFETY: we call set_archetype for each member that implements Fetch
Sourceunsafe fn set_table<'__w>(
_fetch: &mut <EntityInitQuery as WorldQuery>::Fetch<'__w>,
_state: &<EntityInitQuery as WorldQuery>::State,
_table: &'__w Table,
)
unsafe fn set_table<'__w>( _fetch: &mut <EntityInitQuery as WorldQuery>::Fetch<'__w>, _state: &<EntityInitQuery as WorldQuery>::State, _table: &'__w Table, )
SAFETY: we call set_table for each member that implements Fetch
Sourceunsafe fn fetch<'__w>(
_fetch: &mut <EntityInitQuery as WorldQuery>::Fetch<'__w>,
_entity: Entity,
_table_row: TableRow,
) -> <EntityInitQuery as WorldQuery>::Item<'__w>
unsafe fn fetch<'__w>( _fetch: &mut <EntityInitQuery as WorldQuery>::Fetch<'__w>, _entity: Entity, _table_row: TableRow, ) -> <EntityInitQuery as WorldQuery>::Item<'__w>
SAFETY: we call fetch for each member that implements Fetch.
Sourceconst IS_DENSE: bool = true
const IS_DENSE: bool = true
Returns true if (and only if) every table of every archetype matched by this fetch contains
all of the matched components. This is used to select a more efficient “table iterator”
for “dense” queries. If this returns true,
WorldQuery::set_table must be used before
WorldQuery::fetch can be called for iterators. If this returns false,
WorldQuery::set_archetype must be used before WorldQuery::fetch can be called for
iterators.Sourcetype Item<'__w> = EntityInitQueryItem<'__w>
type Item<'__w> = EntityInitQueryItem<'__w>
The item returned by this
WorldQuery
For QueryData this will be the item returned by the query.
For QueryFilter this will be either (), or a bool indicating whether the entity should be included
or a tuple of such things.Sourcetype Fetch<'__w> = EntityInitQueryFetch<'__w>
type Fetch<'__w> = EntityInitQueryFetch<'__w>
Per archetype/table state used by this
WorldQuery to fetch Self::ItemSourcetype State = EntityInitQueryState
type State = EntityInitQueryState
State used to construct a
Self::Fetch. This will be cached inside QueryState,
so it is best to move as much data / computation here as possible to reduce the cost of
constructing Self::Fetch.Sourcefn shrink<'__wlong, '__wshort>(
item: <EntityInitQuery as WorldQuery>::Item<'__wlong>,
) -> <EntityInitQuery as WorldQuery>::Item<'__wshort>where
'__wlong: '__wshort,
fn shrink<'__wlong, '__wshort>(
item: <EntityInitQuery as WorldQuery>::Item<'__wlong>,
) -> <EntityInitQuery as WorldQuery>::Item<'__wshort>where
'__wlong: '__wshort,
This function manually implements subtyping for the query items.
Sourceunsafe fn init_fetch<'__w>(
_world: UnsafeWorldCell<'__w>,
state: &<EntityInitQuery as WorldQuery>::State,
_last_run: Tick,
_this_run: Tick,
) -> <EntityInitQuery as WorldQuery>::Fetch<'__w>
unsafe fn init_fetch<'__w>( _world: UnsafeWorldCell<'__w>, state: &<EntityInitQuery as WorldQuery>::State, _last_run: Tick, _this_run: Tick, ) -> <EntityInitQuery as WorldQuery>::Fetch<'__w>
Creates a new instance of this fetch. Read more
Sourcefn update_component_access(
state: &<EntityInitQuery as WorldQuery>::State,
_access: &mut FilteredAccess<ComponentId>,
)
fn update_component_access( state: &<EntityInitQuery as WorldQuery>::State, _access: &mut FilteredAccess<ComponentId>, )
Sourcefn init_state(world: &mut World) -> EntityInitQueryState
fn init_state(world: &mut World) -> EntityInitQueryState
Creates and initializes a
State for this WorldQuery type.Sourcefn get_state(components: &Components) -> Option<EntityInitQueryState>
fn get_state(components: &Components) -> Option<EntityInitQueryState>
Sourcefn matches_component_set(
state: &<EntityInitQuery as WorldQuery>::State,
_set_contains_id: &impl Fn(ComponentId) -> bool,
) -> bool
fn matches_component_set( state: &<EntityInitQuery as WorldQuery>::State, _set_contains_id: &impl Fn(ComponentId) -> bool, ) -> bool
fn set_access(_state: &mut Self::State, _access: &FilteredAccess<ComponentId>)
fn set_access(_state: &mut Self::State, _access: &FilteredAccess<ComponentId>)
Sets available accesses for implementors with dynamic access such as
FilteredEntityRef
or FilteredEntityMut. Read moreimpl ReadOnlyQueryData for EntityInitQuery
SAFETY: we assert fields are readonly below